@@ -12,8 +12,11 @@ from django.db import IntegrityError
 # to Django's username <= 30 chars limit, which is really too small for
 # arbitrary emails.
 def _email_to_username(email):
-    email = email.lower()  # Emails should be case-insensitive unique
-    return base64.urlsafe_b64encode(hashlib.sha256(email.encode('utf8', 'ignore').digest())[:30]
+    # Emails should be case-insensitive unique
+    email = email.lower()
+    # Deal with internationalized email addresses
+    converted = email.encode('utf8', 'ignore').digest()
+    return base64.urlsafe_b64encode(hashlib.sha256(converted))[:30]
 
 
 def get_user(email, queryset=None):
